@@ -1,5 +1,7 @@
+/* -*-mode: c++; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8-*- */
+
 /*
-** Copyright (C) 2010 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2008-2011 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **
 ** This program is free software; you can redistribute it and/or modify it
 ** under the terms of the GNU General Public License as published by the
@@ -17,58 +19,23 @@
 **
 */
 
-#include <config.h>
-
 #include <glib.h>
-#include <glib-object.h>
-#include <string.h>
-#include <stdio.h> /* for fileno() */
 
-#include "mu-config.h"
 #include "mu-cmd.h"
-#include "mu-log.h"
-
-static gboolean
-init_log (MuConfigOptions *opts)
-{
-	gboolean rv;
-	
-	if (opts->log_stderr)
-		rv = mu_log_init_with_fd (fileno(stderr), FALSE,
-					  opts->quiet, opts->debug);
-	else
-		rv = mu_log_init (opts->muhome, TRUE, opts->quiet,
-				  opts->debug);
-
-	if (!rv)
-		g_printerr ("error: failed to initialize log\n");
-	
-	return rv;
-}
-
+#include "mu-runtime.h"
 
 int
 main (int argc, char *argv[])
 {
-	MuConfigOptions config;
-	gboolean rv;
+	int rv;
 	
-	g_type_init ();
-
-	if (!mu_config_init (&config, &argc, &argv))
+	if (!mu_runtime_init_from_cmdline (&argc, &argv))
 		return 1;
 
-	if (!init_log (&config)) {
-		mu_config_uninit (&config);
-		return 1;
-	}
-			
-	rv = mu_cmd_execute (&config);
+	rv = mu_config_execute (mu_runtime_config());
 
-	mu_log_uninit();
-
-	mu_config_uninit (&config);
+	mu_runtime_uninit ();
 	
-	return rv ? 0 : 1;
+	return rv;
 }
 
