@@ -1,5 +1,5 @@
 /* 
-** Copyright (C) 2010 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2008-2010 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **
 ** This program is free software; you can redistribute it and/or modify it
 ** under the terms of the GNU General Public License as published by the
@@ -17,7 +17,7 @@
 **  
 */
 
-#ifdef HAVE_CONFIG_H
+#if HAVE_CONFIG_H
 #include "config.h"
 #endif /*HAVE_CONFIG_H*/
 
@@ -39,3 +39,10 @@ test_mu_common_get_random_tmpdir (void)
                                 G_DIR_SEPARATOR,
                                 (int)random()*getpid()*(int)time(NULL));
 }
+
+
+void
+black_hole (void)
+{
+	return; /* do nothing */
+}
